@@ -233,7 +233,7 @@ instance CallocPtr Hook where
     boxedPtrCalloc = callocBytes 64
 
 
--- | Construct a `Hook` struct initialized to zero.
+-- | Construct a t'Hook' struct initialized to zero.
 newZeroHook :: MonadIO m => m Hook
 newZeroHook = liftIO $ boxedPtrCalloc >>= wrapPtr Hook
 
@@ -294,7 +294,7 @@ instance AttrInfo HookDataFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Hook.data"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Hook.html#g:attr:data"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Hook.html#g:attr:data"
         })
 
 hook_data :: AttrLabelProxy "data"
@@ -356,7 +356,7 @@ instance AttrInfo HookNextFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Hook.next"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Hook.html#g:attr:next"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Hook.html#g:attr:next"
         })
 
 hook_next :: AttrLabelProxy "next"
@@ -418,7 +418,7 @@ instance AttrInfo HookPrevFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Hook.prev"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Hook.html#g:attr:prev"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Hook.html#g:attr:prev"
         })
 
 hook_prev :: AttrLabelProxy "prev"
@@ -467,7 +467,7 @@ instance AttrInfo HookRefCountFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Hook.refCount"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Hook.html#g:attr:refCount"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Hook.html#g:attr:refCount"
         })
 
 hook_refCount :: AttrLabelProxy "refCount"
@@ -516,7 +516,7 @@ instance AttrInfo HookHookIdFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Hook.hookId"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Hook.html#g:attr:hookId"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Hook.html#g:attr:hookId"
         })
 
 hook_hookId :: AttrLabelProxy "hookId"
@@ -565,7 +565,7 @@ instance AttrInfo HookFlagsFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Hook.flags"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Hook.html#g:attr:flags"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Hook.html#g:attr:flags"
         })
 
 hook_flags :: AttrLabelProxy "flags"
@@ -624,7 +624,7 @@ instance AttrInfo HookFuncFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Hook.func"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Hook.html#g:attr:func"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Hook.html#g:attr:func"
         })
 
 hook_func :: AttrLabelProxy "func"
@@ -639,7 +639,7 @@ hook_func = AttrLabelProxy
 -- @
 -- 'Data.GI.Base.Attributes.get' hook #destroy
 -- @
-getHookDestroy :: MonadIO m => Hook -> m (Maybe GLib.Callbacks.DestroyNotify_WithClosures)
+getHookDestroy :: MonadIO m => Hook -> m (Maybe GLib.Callbacks.DestroyNotify)
 getHookDestroy s = liftIO $ withManagedPtr s $ \ptr -> do
     val <- peek (ptr `plusPtr` 56) :: IO (FunPtr GLib.Callbacks.C_DestroyNotify)
     result <- SP.convertFunPtrIfNonNull val $ \val' -> do
@@ -673,9 +673,9 @@ instance AttrInfo HookDestroyFieldInfo where
     type AttrBaseTypeConstraint HookDestroyFieldInfo = (~) Hook
     type AttrAllowedOps HookDestroyFieldInfo = '[ 'AttrSet, 'AttrGet, 'AttrClear]
     type AttrSetTypeConstraint HookDestroyFieldInfo = (~) (FunPtr GLib.Callbacks.C_DestroyNotify)
-    type AttrTransferTypeConstraint HookDestroyFieldInfo = (~)GLib.Callbacks.DestroyNotify_WithClosures
+    type AttrTransferTypeConstraint HookDestroyFieldInfo = (~)GLib.Callbacks.DestroyNotify
     type AttrTransferType HookDestroyFieldInfo = (FunPtr GLib.Callbacks.C_DestroyNotify)
-    type AttrGetType HookDestroyFieldInfo = Maybe GLib.Callbacks.DestroyNotify_WithClosures
+    type AttrGetType HookDestroyFieldInfo = Maybe GLib.Callbacks.DestroyNotify
     type AttrLabel HookDestroyFieldInfo = "destroy"
     type AttrOrigin HookDestroyFieldInfo = Hook
     attrGet = getHookDestroy
@@ -686,7 +686,7 @@ instance AttrInfo HookDestroyFieldInfo where
         GLib.Callbacks.mk_DestroyNotify (GLib.Callbacks.wrap_DestroyNotify Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Hook.destroy"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Hook.html#g:attr:destroy"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Hook.html#g:attr:destroy"
         })
 
 hook_destroy :: AttrLabelProxy "destroy"
@@ -773,7 +773,7 @@ instance (signature ~ (Hook -> m Int32), MonadIO m) => O.OverloadedMethod HookCo
 instance O.OverloadedMethodInfo HookCompareIdsMethodInfo Hook where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.Hook.hookCompareIds",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-Hook.html#v:hookCompareIds"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-Hook.html#v:hookCompareIds"
         })
 
 
